/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2011, 2013. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */

define(["dojo/dom", "dojo/on", "com/ibm/mobile/phonegapshow/util"],
  function(dom, on, util) {


    //-------------------------------------------------------------------------
    // Compass
    //-------------------------------------------------------------------------
    var watchCompassId = null;

    /**
     * Set compass status
     */
    function setCompassStatus(status) {
        dom.byId('compass_status').innerHTML = status;
    };
	
	function getCompassData() {
        console.log("getCompass()");

        // Stop compass if running
        stopCompass();

        // Success callback
        var success = function(a){
            dom.byId('compassHeading').innerHTML = util.roundNumber(a.magneticHeading);
        };

        // Fail callback
        var fail = function(e){
            console.log("getCompass fail callback with error code "+e);
            setCompassStatus(navigator.compass.ERROR_MSG[e]);
        };

        // Make call
        var opt = {};
        navigator.compass.getCurrentHeading(success, fail, opt);

	};

    /**
     * Start watching compass
     */
    var watchCompass = function() {
        console.log("watchCompass()");

        // Success callback
        var success = function(a){
            dom.byId('compassHeading').innerHTML = util.roundNumber(a.magneticHeading);
        };

        // Fail callback
        var fail = function(e){
            console.log("watchCompass fail callback with error code "+e);
            stopCompass();
            setCompassStatus(navigator.compass.ERROR_MSG[e]);
        };

        // Update heading every 1 sec
        var opt = {};
        opt.frequency = 1000;
        watchCompassId = navigator.compass.watchHeading(success, fail, opt);

        setCompassStatus("Watching");
    };

    /**
     * Stop watching the compass
     */
    var stopCompass = function() {
        console.log("stopCompass()");
        setCompassStatus("Stopped");
        if (watchCompassId) {
            navigator.compass.clearWatch(watchCompassId);
            watchCompassId = null;
        }
    };

	
	return {
		init: function() {
			console.log("initializeCompassControls()");
			setCompassStatus("Stopped");
			on(dom.byId("getHeadingBtn"), "click", getCompassData);
			on(dom.byId("startCompassBtn"), "click", watchCompass);
			on(dom.byId("stopCompassBtn"), "click", stopCompass);
		}
	};
});
